

local date = require"date"
local pg = require"postgres"


math.randomseed(os.time())


pg.typeFormat{
	setDate = function(d) return d:fmt"%F %T", "timestamp" end,
	setLocalDate = function(d) return d:fmt"%F %T %Z", "timestamptz" end,
	setUTCDate = function(d) return d:fmt"%F %T UTC", "timestamptz" end
}


pg.typeParser{
	timestamp = date,
	timestamptz = date
}


local conn = assert(pg.connect"host=* dbname=* user=* password=*")


assert(conn:execute[[
	CREATE TEMP TABLE test (
		id	int4 PRIMARY KEY,
		edate	timestamptz,
		price	numeric(7,2),
		demand	int2,
		notes	text
	)
]])


assert(conn:begin())

local stmt = conn:statement[[
	INSERT INTO test VALUES ( $1, $2, $3, $4, $5 )
]]
for i = 1, 100 do
	stmt:setInteger(1, i)
	stmt:setLocalDate(2, date(2007,1,1):addhours(i))
	stmt:setNumber(3, math.random(1000, 100000)/100)
	stmt:setInteger(4, math.random(6500, 9800))
	stmt:setString(5, "test " .. string.format("%02d", 100 - i))
	assert(stmt:execute())
end
print(stmt)
stmt:close()

assert(conn:commit())


local stmt = conn:statement[[
	SELECT	edate,
		price,
		demand
	FROM	test
	WHERE	price > $1
	AND	demand < $2
	ORDER BY price DESC
]]
stmt:setNumber(1, 300.00)
stmt:setInteger(2, 7500, 2)
local res, count = assert(stmt:selectResultSet())
for k, v in ipairs(res) do
	print(v.edate:copy():tolocal():fmt"%F %T", v.price, v.demand)
end
print""
print(count)
print""
print(stmt)
stmt:close()


conn:close()

